@@ -51,6 +51,33 @@ class Manager(object):
         # return Counter(values)
 
             
+    def get_index_as_partial_dict(self, index, cols):
+        l = []
+        search_dict = {
+        "_source": cols,
+        "query": {
+          "match_all": {  
+          }
+        }
+        }
+
+        s = Search().from_dict(search_dict).index(index).scan()
+        for hit in tqdm(s):
+        d = hit.to_dict()
+        d["_id"] = hit.meta.id
+        l.append(d)
+        return l
+        
+
+    def gendata(index, docs):
+    for doc in docs:
+        yield {
+            "_op_type": "update",
+            "_index": index,
+            "_id": doc["_id"],
+            "doc": {doc['column']: doc["value"]}
+        }
+        print("end gen")
 
 
     def get_from_index(self, index, body: [str, dict]):
